==> smalltalk-2.3.1.tar.gz: smalltalk-2.3.1/lib-src/socketx.h <==
/******************************** -*- C -*- ****************************
 *
 *      Common layer for BSD and Windows sockets
 *
 *
 ***********************************************************************/

/***********************************************************************
 *
 * Copyright 2003, 2006 Free Software Foundation, Inc.
 * Written by Paolo Bonzini.
 *
 * This file is part of GNU Smalltalk.
 *
 * GNU Smalltalk is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2, or (at your option) any later
 * version.
 *
 * Linking GNU Smalltalk statically or dynamically with other modules is
 * making a combined work based on GNU Smalltalk.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * In addition, as a special exception, the Free Software Foundation
 * give you permission to combine GNU Smalltalk with free software
 * programs or libraries that are released under the GNU LGPL and with
 * independent programs running under the GNU Smalltalk virtual machine.
 *
 * You may copy and distribute such a system following the terms of the
 * GNU GPL for GNU Smalltalk and the licenses of the other code
 * concerned, provided that you include the source code of that other
 * code when and as the GNU GPL requires distribution of source code.
 *
 * Note that people who make modified versions of GNU Smalltalk are not
 * obligated to grant this special exception for their modified
 * versions; it is their choice whether to do so.  The GNU General
 * Public License gives permission to release a modified version without
 * this exception; this exception also makes it possible to release a
 * modified version which carries forward this exception.
 *
 * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * GNU Smalltalk; see the file COPYING.  If not, write to the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 ***********************************************************************/

#ifndef GST_SOCKETX_H
#define GST_SOCKETX_H

#ifdef HAVE_INET_SOCKETS

#ifdef __MSVCRT__
#include <winsock2.h>
#define is_socket_error(err)      (WSAGetLastError() == WSA##err)
#define clear_socket_error()      WSASetLastError(0)
#else /* !__MSVCRT__ */
#include <errno.h>
#include <sys/select.h>
#include <sys/socket.h>
#include <netdb.h>
#include <netinet/in.h>
#define closesocket(x)            close(x)
#define is_socket_error(err)      (errno == (err))
#define clear_socket_error()      (errno = 0)
#endif /* !__MSVCRT__ */

#endif /* HAVE_INET_SOCKETS */

#endif /* GST_SOCKETX_H */

==> smalltalk-2.3.6.tar.gz: smalltalk-2.3.6/lib-src/socketx.h <==
/******************************** -*- C -*- ****************************
 *
 *      Common layer for BSD and Windows sockets
 *
 *
 ***********************************************************************/

/***********************************************************************
 *
 * Copyright 2003, 2006, 2007 Free Software Foundation, Inc.
 * Written by Paolo Bonzini.
 *
 * This file is part of GNU Smalltalk.
 *
 * GNU Smalltalk is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2, or (at your option) any later
 * version.
 *
 * Linking GNU Smalltalk statically or dynamically with other modules is
 * making a combined work based on GNU Smalltalk.  Thus, the terms and
 * conditions of the GNU General Public License cover the whole
 * combination.
 *
 * In addition, as a special exception, the Free Software Foundation
 * give you permission to combine GNU Smalltalk with free software
 * programs or libraries that are released under the GNU LGPL and with
 * independent programs running under the GNU Smalltalk virtual machine.
 *
 * You may copy and distribute such a system following the terms of the
 * GNU GPL for GNU Smalltalk and the licenses of the other code
 * concerned, provided that you include the source code of that other
 * code when and as the GNU GPL requires distribution of source code.
 *
 * Note that people who make modified versions of GNU Smalltalk are not
 * obligated to grant this special exception for their modified
 * versions; it is their choice whether to do so.  The GNU General
 * Public License gives permission to release a modified version without
 * this exception; this exception also makes it possible to release a
 * modified version which carries forward this exception.
 *
 * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * GNU Smalltalk; see the file COPYING.  If not, write to the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 ***********************************************************************/

#ifndef GST_SOCKETX_H
#define GST_SOCKETX_H

#include "config.h"

#ifdef HAVE_INET_SOCKETS

#ifdef __MSVCRT__
#include <windows.h>
#include <winsock2.h>
#include <io.h>

#define is_socket_error(err)      (WSAGetLastError() == WSA##err)
#define clear_socket_error()      WSASetLastError(0)

#define ESHUTDOWN WSAESHUTDOWN
#define ENOTCONN WSAENOTCONN
#define ECONNRESET WSAECONNRESET
#define ECONNABORTED WSAECONNABORTED
#define ENETRESET WSAENETRESET

typedef int nfds_t;

/* re-define FD_ISSET to avoid a WSA call while we are not using 
 * network sockets */
#undef FD_ISSET
#define FD_ISSET(fd, set) win_fd_isset(fd, set)

static inline int
win_fd_isset (int fd, fd_set * set)
{
  int i;
  if (set == NULL)
    return 0;

  for (i = 0; i < set->fd_count; i++)
    if (set->fd_array[i] == fd)
      return 1;

  return 0;
}

int win_select(int n, fd_set *rfds, fd_set *wfds, fd_set *efds, struct timeval *ptv);
int win_recv(int fd, void* buffer, int n, int flags);

#undef select
#define select win_select

#undef recv
#define recv win_recv

#else /* !__MSVCRT__ */

#include <errno.h>
#include <sys/select.h>
#include <sys/socket.h>
#include <netdb.h>
#include <netinet/in.h>
#define closesocket(x)            close(x)
#define is_socket_error(err)      (errno == (err))
#define clear_socket_error()      (errno = 0)
#endif /* !__MSVCRT__ */

#endif /* HAVE_INET_SOCKETS */

#endif /* GST_SOCKETX_H */
